@@ -19,7 +19,8 @@ class UserRoom_Recorder_Exporter_Handler:
     def create_exporter(self, recorder_id, config):
         create_exporter_payload = {
             "recorder_id": recorder_id,
-            "exporter_config": config
+            "exporter_config": config,
+            "unlimited": "true"
         }
         payload_json = json.dumps(create_exporter_payload)
         response = self._exporter_api.create_exporter(payload_json)
