@@ -15,6 +15,8 @@ class Gateway_HttpHandler:
         self._customer_auth  = customer_auth_handler
         self._http_service = HttpService()
         
+        if customer_auth_handler.get_access_token() is None: 
+            raise ValueError("no token for customer, failed to initialize gateway")
         self._headers =  {
                 "Authorization": "Bearer " + customer_auth_handler.get_access_token()
         }
