@@ -7,12 +7,23 @@ Created on Fri Sep 10 12:37:54 2021
 
 
 from neurospeed.utils.http_service import HttpService
+from neurospeed.utils.helper_service import UtilService
+
 
 class Auth_AS_User_Handler:
 
     def __init__(self, user_config):
         self._contex = "User_Auth_Handler - "
+        
+        
+            
         self._user_config = user_config
+        if not "HIA_ID" in user_config.keys():
+            self._user_config["HIA_ID"] = UtilService.generateId(6)
+            
+        if not "Verbose_socket_log" in user_config.keys():
+            self._user_config["Verbose_socket_log"] = "False"
+            
         self._user_username = self._user_config["username"]
         self._access_token = None
         self._login_status = None
