@@ -22,4 +22,4 @@ class UtilService:
       
         
     def generateId(id_length):
-        return ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(id_length));
\ No newline at end of file
+        return ''.join(random.choice(string.ascii_uppercase + string.digits) for _ in range(id_length))
\ No newline at end of file
