@@ -9,7 +9,7 @@ Created on Fri Sep 11 20:07:52 2021
 import requests
 import json
 from neurospeed.utils.api_config_service import ApiConfig
-
+import copy 
 class HttpService:    
     
     def __init__(self):
@@ -44,8 +44,17 @@ class HttpService:
             
     def POST_request(self, endpoint, payload, headers = {}):
         api_url = self._api_url + endpoint
-        print('doing HTTP POST to url: {} payload {}'.format( api_url, payload ))
-
+      
+        try:
+            clean_payload = copy.deepcopy(payload)
+            for key in payload:
+                if key == "password":
+                    clean_payload.pop(key)
+                    
+            print('doing HTTP POST to url: {} payload {}'.format( api_url, clean_payload ))     
+        except Exception as err:
+            pass
+           
         response = None
         try:
             response = requests.post(api_url, data=payload, headers =headers)
